@@ -741,7 +741,7 @@ pchSvg <- function(shape, width, height, color, fillColor, opacity,
         height = height,
         width = width,
         stroke = 'transparent',
-        fill = fillColor,
+        fill = coalesce_missing(fillColor, color),
         'fill-opacity' = fillOpacity,
         ...
       ),
@@ -751,7 +751,7 @@ pchSvg <- function(shape, width, height, color, fillColor, opacity,
         cy = height / 2 + strokeWidth,
         r =  height *  3 / 4 / 2,
         stroke = 'transparent',
-        fill = fillColor,
+        fill = coalesce_missing(fillColor, color),
         'fill-opacity' = fillOpacity,
         ...
       ),
@@ -760,7 +760,7 @@ pchSvg <- function(shape, width, height, color, fillColor, opacity,
         points = drawTriangle(width = width, height = height,
           offset = strokeWidth),
         stroke = 'transparent',
-        fill = fillColor,
+        fill = coalesce_missing(fillColor, color),
         'fill-opacity' = fillOpacity,
         ...
       ),
@@ -769,7 +769,7 @@ pchSvg <- function(shape, width, height, color, fillColor, opacity,
         points = drawDiamond(width = width, height = height,
           offset = strokeWidth),
         stroke = 'transparent',
-        fill = fillColor,
+        fill = coalesce_missing(fillColor, color),
         'fill-opacity' = fillOpacity,
         ...
       ),
@@ -779,7 +779,7 @@ pchSvg <- function(shape, width, height, color, fillColor, opacity,
         cy = height / 2 + strokeWidth,
         r =  height *  4 / 4 / 2,
         stroke = 'transparent',
-        fill = fillColor,
+        fill = coalesce_missing(fillColor, color),
         'fill-opacity' = fillOpacity,
         ...
       ),
@@ -789,7 +789,7 @@ pchSvg <- function(shape, width, height, color, fillColor, opacity,
         cy = height / 2 + strokeWidth,
         r = height *  2 / 4 / 2,
         stroke = 'transparent',
-        fill = fillColor,
+        fill = coalesce_missing(fillColor, color),
         'fill-opacity' = fillOpacity,
         ...
       ),
@@ -858,6 +858,9 @@ pchSvg <- function(shape, width, height, color, fillColor, opacity,
   }
   pchShape[[shape]]
 }
+coalesce_missing <- function(x, y) {
+  if (missing(x)) y else x
+}
 #' @param svg
 #'
 #' inner svg tags for symbol
